==> postLDAPadmin_admin-2.00.tar.gz: postldapadmin/user/csv/index.php <==
<?php

/*
 * postLDAPadmin
 *
 * Copyright (C) 2006,2007 DesigNET, INC.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

/***********************************************************
 * CSV
 *
 * $RCSfile: index.php,v $
 * $Revision: 1.1.1.1 $
 * $Date: 2010/04/22 01:52:47 $
 **********************************************************/

include_once("../../initial");
include_once("lib/dglibpostldapadmin");
include_once("lib/dglibcommon");
include_once("lib/dglibpage");
include_once("lib/dglibsess");
include_once("lib/dglibldap");

/***********************************************************
 * 饹: ˥塼
 **********************************************************/
Class my_page extends page {

    /***********************************************************
     * ܥǥɽʥС饤ɡ
     **********************************************************/
    function display_body() {

        global $web_conf;
        global $sesskey;

        print <<<EOD
<script type="text/javascript">
<!--
  function resultwindow() {
      window.open("", "resultwindow", "width=500,height=400,toolbar=no,scrollbars=yes");
      document.form.target = "resultwindow";
      document.form.submit();
  }

  function uploadconfirm(msg){
      if (msgConfirm(msg)) {
          return resultwindow();
      } else {
          return false;
      }
  }
// -->
</script>
<form name="form" method="POST" action="result.php" enctype="multipart/form-data">
  <table class="table">
    <tr>
      <td class="key1">ư</td>
      <td class="value">
      <input type="radio" name="runtype" value="add" checked>Ͽ
      <input type="radio" name="runtype" value="del"></td>
    </tr>
    <tr>
      <td class="key1" rowspan="2">ץ</td>
      <td class="value">
      <input type="checkbox" name="change" value=ON>¸Υǡ񤭡ʺξ̵뤵ޤ</td>
    <tr>
      <td class="value">
      <input type="checkbox" name="err" value=ON>顼ξ³</td>
    </tr>
    <tr>
      <td class="key1">åץɥե</td>
      <td class="value">
        <input type="file" name="uploadfile" size=50></td>
    </tr>
    <tr>
      <td class="key1">եå</td>
      <td class="value"><input type="submit" name="fcheck" value="եå" onClick="resultwindow()"></td>
    </tr>
  </table><br>
  <input type="hidden" name="sk" value="$sesskey">
  <input type="submit" name="upload" value="" onClick="return uploadconfirm('CSV򳫻Ϥޤ\\nǤ?')">
</form>
EOD;

    }
};

/***********************************************************
 * 
 **********************************************************/
/* 󥹥󥹺 */
$pg = new my_page();

/* ե롢ִեɹåΥå */
$ret = init();
if ($ret === FALSE) {
    $sys_err = TRUE;
    $pg->display(NULL);
    exit (1);
}

/***********************************************************
 * ɽ
 **********************************************************/
$pg->display(CONTENT);

?>

==> postLDAPadmin_admin-2.20.tar.gz: postldapadmin/user/csv/index.php <==
<?php

/*
 * postLDAPadmin
 *
 * Copyright (C) 2006,2007 DesigNET, INC.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

/***********************************************************
 * CSV
 *
 * $RCSfile: index.php,v $
 * $Revision: 1.2 $
 * $Date: 2010/06/10 05:26:46 $
 **********************************************************/

include_once("../../initial");
include_once("lib/dglibpostldapadmin");
include_once("lib/dglibcommon");
include_once("lib/dglibpage");
include_once("lib/dglibsess");
include_once("lib/dglibldap");

/***********************************************************
 * 饹: ˥塼
 **********************************************************/
Class my_page extends page {

    /***********************************************************
     * ܥǥɽʥС饤ɡ
     **********************************************************/
    function display_body() {

        global $web_conf;
        global $sesskey;

        print <<<EOD
<script type="text/javascript">
<!--
  function resultwindow() {
      window.open("", "resultwindow", "width=500,height=400,toolbar=no,scrollbars=yes");
      document.form.target = "resultwindow";
      document.form.submit();
  }

  function uploadconfirm(msg){
      if (msgConfirm(msg)) {
          return resultwindow();
      } else {
          return false;
      }
  }
// -->
</script>
<form name="form" method="POST" action="result.php" enctype="multipart/form-data">
  <table class="table">
    <tr>
      <td class="key1">ư</td>
      <td class="value">
      <input type="radio" name="runtype" value="add" checked>Ͽ
      <input type="radio" name="runtype" value="del"></td>
    </tr>
    <tr>
      <td class="key1" rowspan="2">ץ</td>
      <td class="value">
      <input type="checkbox" name="change" value=ON>¸Υǡ񤭡ʺξ̵뤵ޤ</td>
    <tr>
      <td class="value">
      <input type="checkbox" name="err" value=ON>顼ξ³</td>
    </tr>
    <tr>
      <td class="key1">åץɥե</td>
      <td class="value">
        <input type="file" name="uploadfile" size=50></td>
    </tr>
    <tr>
      <td class="key1">եå</td>
      <td class="value"><input type="submit" name="fcheck" value="" class="file_check_btn" onClick="resultwindow()"></td>
    </tr>
  </table><br>
  <input type="hidden" name="sk" value="$sesskey">
  <input type="submit" name="upload" value="" class="mod_btn" onClick="return uploadconfirm('CSV򳫻Ϥޤ\\nǤ?')">
</form>
EOD;

    }
};

/***********************************************************
 * 
 **********************************************************/
/* 󥹥󥹺 */
$pg = new my_page();

/* ե롢ִեɹåΥå */
$ret = init();
if ($ret === FALSE) {
    $sys_err = TRUE;
    $pg->display(NULL);
    exit (1);
}

/***********************************************************
 * ɽ
 **********************************************************/
$pg->display(CONTENT);

?>
